betty.project.extension.demo.serve module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.demo.serve module

Tools to serve demonstration sites.

final class betty.project.extension.demo.serve.DemoServer

  Bases: `Server`

  Serve the Betty demonstration site.

  __init__(app: App)
  property public_url: str

    The server’s public URL.

  async start() → None

    Start the server.

  async stop() → None

    Stop the server.